****************************************************************
* Program name:  rental_visit.sas
* Project:       Housing Discrimination Study Phase I
*
*  Final version: October 29, 2001 by Steve Ross
*
*  This program generates a clean sample of rental site
*  visits for all testers.  The site visits for both the
*  majority and minority testers are merged with the sample of 
*  paired assignments from fassign2.ssd01.  A final sample of
*  completed rental tests is created where each tester made at 
*  least one visit to the real estate agency.  
*
* Input Files:   rental.ssd01, fassign2.ssd01, smagrent.ssd01
*
* Output Files:  finrent.ssd01
*
*                                            
****************************************************************;

options nocenter ;

libname hds2000 '/mnt/jayhawk/jayproj/hds2000' ;

filename fassign2 '/mnt/jayhawk/jayproj/hds2000/fassign2.ssd01' ;
filename finrent '/mnt/jayhawk/jayproj/hds2000/finrent.ssd01' ;
filename rental '/mnt/jayhawk/jayproj/hds2000/rental.ssd01' ;
filename smagrent '/mnt/jayhawk/jayproj/hds2000/smagrent.ssd01' ;
filename seqrent '/mnt/jayhawk/jayproj/hds2000/seqrent.ssd01';

/* read information about whether testers saw the sameagent.  This
variable was created by a manual inspection of agent names.  The names
were taken from the variables W/MAGNAME1-5 and the actual agent was
identified by the testers self-report concerning who they met with which
is contained in W/MAGMETW.  The information is stored in the variable
same which is one if they saw the sameagent */


data smagrent ;
   set hds2000.smagrent ;
   sameagnt=same ;
   keep control sameagnt ;
proc sort ; 
  by control ;

/* read information on assigned order of tester visits */

data seqrent ;
   set hds2000.seqrent ;
   order=sequence ;
   keep control order ;

proc sort ;
   by control ;

/* load information on rental site visit report forms */

data rental dup ;
  set hds2000.rental ;
  if   (control='AT-RB-0301' and testerid='405') or
       (control='DN-RB-0514' and testerid='201') or
       (control='LA-RB-0815' and testerid='13 ') or
       (control='LA-RB-0815' and testerid='75 ') or
       (control='LA-RB-0920' and testerid='25 ') or
       (control='LN-RB-1533' and testerid='62 ') or
       (control='LN-RB-1629' and testerid='98 ') or
       (control='LN-RH-1523' and testerid='365') or
       (control='NN-RB-2432' and testerid='13 ') or
       (control='NN-RB-2432' and testerid='53 ') or
       (control='NO-RB-0606' and testerid='206') or
       (control='NX-RB-1701' and testerid='11 ') or
       (control='PT-RB-1814' and testerid='20 ') or
       (control='PT-RB-2408' and testerid='37 ') or
       (control='PX-RN-1302' and testerid='006') or
       (control='PX-RN-1302' and testerid='106') or
       (control='SA-RH-2425' and testerid='121') then output dup ;
          else output rental ;

proc contents ;

proc sort data=dup ;
  by control testerid ;

/* delete duplicate site visit report forms */

data dup ;
  set dup ;
  if _N_ in (1,3,5,7,10,11,13,15,17,19,21,23,25,27,30,31,33) then
    output dup ; else delete ;

/* delete any other known duplictate report forms based
on UI variables */

data rental ;
  set rental dup ;
  ntyper=substr(control,4,1) ;
  if control='HO-RB-1908' then del_rec=0 ;
  if control='LA-RB-0919' then duplicat=0 ;
  if duplicat=1 or del_rec=1 or ntyper='S' then delete ;
    else output rental ;

/* load sample of completed tests */

data assign ;
  set hds2000.fassign2 ;
  if control='CH-RB-0811' and mtestid='I B-F' then mtestid= 'BF-TAYL' ;
  ntype=substr(control,4,1) ;
  if ntype='S' or control='MN-RS-0804' then delete ;
     else output assign ;

proc sort ;
  by control wtestid ;

/* save information on white treatment during test */

data wrsvrf ;
  set rental ;
  wtestid=testerid ;  
  wavladv=ravlblad ;
  wtotunit=rtotunit ;
  wsamebed=rsamebed ;
  wminbed=rminbed ; 
  wqincome=rqincome ;
  winvtapp=rinvtapp ;
  wfutcon1=rfutcon1 ;
  wfutcon2=rfutcon2 ;
  wfutcon3=rfutcon3 ;
  wfutcon4=rfutcon4 ;
  wfeereq=rtfeereq ;
  wincent=rincent ;
  wmeetag=rmeetag ;
  wagdecln=ragdecln ;
  wagmetw=ragmetw ;
  wagname1=ragname1 ;
  wagname2=ragname2 ;
  wagname3=ragname3 ;
  wagname4=ragname4 ;
  wagname5=ragname5 ;
  wbegt_am=rbegt_am ;
  wbegt_h=rbegt_h ;
  wbegt_m=rbegt_m ;
  wendt_am=rendt_am ;
  wendt_h=rendt_h ;
  wendt_m=rendt_m ;
  wwaittim=rwaittim ;
  wsugdiff=rsugdiff ;
  wagqual=ragqual ;
  wwait=rwait ;
  wontlist=rontlist ;
  wlistlng=rlistlng ;
  wvdate_m=rdate_m ;
  wvdate_y=rdate_y ;
  wvdate_d=rdate_d ;
  wcredchk=rcrdreq ;
  keep control wtestid wavladv wtotunit wsamebed wminbed 
     wqincome winvtapp wfutcon2 wfeereq wincent wmeetag wagdecln 
     wbegt_am wbegt_h wbegt_m wendt_am wendt_h wendt_m wwaittim 
     wagqual wagmetw wagname1 wagname2 wagname3 wagname4 wagname5
     wwait wontlist wlistlng wfutcon1 wfutcon3 wfutcon4 wsugdiff
     wvdate_m wvdate_y wvdate_d wcredchk ;

proc contents ;


proc sort ;
  by control wtestid ;

/* merge white treatment information with sample of paired assignments  */

data assign ;
  merge assign (in=q1) wrsvrf (in=q2) ;
    by control wtestid ;
  wsvrf=q2 ;
  if q1 then output assign ;
      else delete ;

proc sort data=assign ;
  by control mtestid ;

/* save information on minority treatment during test */

data mrsvrf ;
  set rental ;
  mtestid=testerid ;  
  mavladv=ravlblad ;
  mtotunit=rtotunit ;
  msamebed=rsamebed ;
  mminbed=rminbed ; 
  mqincome=rqincome ;
  minvtapp=rinvtapp ;
  mfutcon1=rfutcon1 ;
  mfutcon2=rfutcon2 ;
  mfutcon3=rfutcon3 ;
  mfutcon4=rfutcon4 ;
  mfeereq=rtfeereq ;
  mincent=rincent ;
  mmeetag=rmeetag ;
  magdecln=ragdecln ;
  magmetw=ragmetw ;
  magname1=ragname1 ;
  magname2=ragname2 ;
  magname3=ragname3 ;
  magname4=ragname4 ;
  magname5=ragname5 ;
  mbegt_am=rbegt_am ;
  mbegt_h=rbegt_h ;
  mbegt_m=rbegt_m ;
  mendt_am=rendt_am ;
  mendt_h=rendt_h ;
  mendt_m=rendt_m ;
  mwaittim=rwaittim ;
  magqual=ragqual ;
  mwait=rwait ;
  montlist=rontlist ;
  mlistlng=rlistlng ;
  msugdiff=rsugdiff ;
  mvdate_m=rdate_m ;
  mvdate_y=rdate_y ;
  mvdate_d=rdate_d ;
  mcredchk=rcrdreq ;
  keep control mtestid mavladv mtotunit msamebed mminbed 
     mqincome minvtapp mfutcon2 mfeereq mincent mmeetag magdecln 
     mbegt_am mbegt_h mbegt_m mendt_am mendt_h mendt_m mwaittim
     magqual magmetw magname1 magname2 magname3 magname4 magname5 
     mwait montlist mlistlng mfutcon1 mfutcon3 mfutcon4 msugdiff
     mvdate_m mvdate_y mvdate_d mcredchk ;

proc sort ;
  by control mtestid ;

/* merge minority treatment information with sample of tests */

data assign ;
  merge assign (in=q1) mrsvrf (in=q2) ;
    by control mtestid ;
  msvrf=q2 ;
  if q1 then output assign ;
      else delete ;

/* merge same agent information into sample of rental tests */

data assign ;
  merge assign (in=q1) smagrent seqrent ;
    by control ;
  if q1 ;

/* save sample of tests in which each tester completed a site
visit report form */

data hds2000.finrent problem ;
  set assign ;
  nsite=substr(control,1,2) ;
  if  msvrf=1 and wsvrf=1 then output hds2000.finrent ;
    else output problem ;

proc freq ;
  tables sameagnt wsex*msex wcredchk mcredchk ;



run;
	