****************************************************************
* Program name:  sales_merge.sas
* Project:       Housing Discrimination Study Phase I
*
*  Final version: February 7, 2002 by Steve Ross
*
*  This program merges together the final sample of sales tests
*  with counts and means from the sample of rental units recommended
*  or inspected by the testers, as well as information on whether
*  follow-up contact was made by the real estate agent.  The 
*  resulting sample is used to create treatment variables for the
*  basic analysis that replicates the 1989 HDS.
*
* Input Files:   finsales.ssd01, follow.ssd01, rechome2.ssd01, agcydem.ssd01
*
* Output Files:  fnslsmrg.ssd01
*                                            
****************************************************************;

options nocenter ;

libname hds2000 '/mnt/jayhawk/jayproj/hds2000' ;


filename fassign2 '/mnt/jayhawk/jayproj/hds2000/fassign2.ssd01' ;
filename finsales '/mnt/jayhawk/jayproj/hds2000/finsales.ssd01' ;
filename fnslsmrg '/mnt/jayhawk/jayproj/hds2000/fnslsmrg.ssd01' ;
filename follow '/mnt/jayhawk/jayproj/hds2000/follow.ssd01' ;
filename rechome2 '/mnt/jayhawk/jayproj/hds2000/rechome2.ssd01' ;
filename agcydem '/mnt/jayhawk/jayproj/hds2000/agcydem.ssd01' ;

/* load information on office location demographics */

data office ;
  set hds2000.agcydem ;
  
proc sort ; by control ;

/* load final sales test sample */

data tests ;
  set hds2000.finsales ;

/* load info on follow up contact */
 
data follow ;
  set hds2000.follow ;
  if totcnt2>0 then follow=1 ;
    else follow=0 ;
  keep control testerid follow ;

proc sort ;
  by control testerid ;

data unit ;
  set hds2000.rechome2 ;

  /*  first or second visit */

  if hadhome1=0 or hadhome1=. then hadhome1=hadhome2 ;
  if hinspct1=0 or hinspct1=. then hinspct1=hinspct2 ;
  if hbedrms1=0 or hbedrms1=. then hbedrms1=hbedrms2 ;
  if haskpri1=0 or haskpri1=. then haskpri1=haskpri2 ;

  if hbedrms1=0 then hbedrms1=. ;
  if haskpri1=0 then haskpri1=. ;

  count=1 ;

  /*  determine whether unit is similar (same number of bedroomes)
    or whether unit is acceptable (at least minimum number of
    bedrooms */
  
  if abedreql<=hbedrms1<=abedrequ or hbedrms1=. or abedreql=. then meetbreq=1 ;
    else if hbedrms1 in (0.5, 1.5, 2.5, 3.5, 4.5, 5.5) then do ;
       if abedreql<=hbedrms1-0.5<=abedrequ or abedreql<=hbedrms1+0.5<=
             abedrequ   then meetbreq=1 ;
       else meetbreq=0 ;
       end ;
     else meetbreq=0 ;

  if hbedrms1+0.5>=abedmin then meetbmin=1 ;
    else if meetbreq=1 then meetbmin=1 ;
    else meetbmin=0 ;


  /* advertised unit and inspection */

  if hadhome1=1 then advunit=1 ;
    else advunit=0 ;
  if hinspct1=1 then inspect=1 ;
    else inspect=0 ;
  if inspect=1 and advunit=1 then inspadv=1 ;
    else inspadv=0 ;
  if advunit=1 and meetbreq=1 
     then advmeet=1 ; else advmeet=0 ;
   if advunit=1 and meetbmin=1 
     and advmeet=0 then advacc=1 ; else advacc=0 ;

   if advunit=1 then advaskp=haskpri1 ;
     else advaskp=. ;

  /* similar unit and inspection */

  if meetbreq=1 and advunit=0 then similar=1 ;
    else similar=0 ;
  if inspect=1 and similar=1 then inspsim=1 ;
    else inspsim=0 ;
 
  /* acceptable unit and inspection */

  if meetbmin=1 and advunit=0 and similar=0
        then accept=1 ;
    else accept=0 ;
  if inspect=1 and accept=1 then inspacc=1 ;
    else inspacc=0 ;

/* record geographic information relevant to advertised or
    similar units */

  if advunit=1 then advmval=mval00 ;
       else advmval=. ;
  if advunit=1 then advpci=pci00 ;
        else advpci=. ;
  if advunit=1 then advpblk=pctblk ;
       else advpblk=. ;
  if advunit=1 then advphsp=pcthisp ;
         else advphsp=. ;
  if advunit=1 then advpown=pctownoc ;
         else advpown=. ;
  if advunit=1 then advpov=povrat90 ;
       else advpov=. ;


   if advunit^=1 then simaskp=haskpri1 ;
     else simaskp=. ;


    if advunit^=1 then simmval=mval00 ;
       else simmval=. ;
    if advunit^=1 then simpci=pci00 ;
        else simpci=. ;
    if advunit^=1 then simpblk=pctblk ;
       else simpblk=. ;
    if advunit^=1 then simphsp=pcthisp ;
       else simphsp=. ;
    if advunit^=1 then simpown=pctownoc ;
       else simpown=. ;
    if advunit^=1 then simpov=povrat90 ;
       else simpov=. ;



proc sort data=unit ;
  by control testerid ;

/* create average of unit characteristics by visit and by
  type of unit, e.g. advertised, similar, or acceptable unit  */

  


/* create variables on number of advertised units in test combining
  units across the two visits */


proc means noprint data=unit ;
  by control testerid ;
  var advmval advpci advpblk advphsp advpown advpov advaskp
        simmval simpci simpblk simphsp simpown simpov simaskp ;
  output out=mnunit mean=amval apci apblk aphsp apown apov aaskp
       smval spci spblk sphsp spown spov saskp 
       stderr=sdmval ;

/* create variables on numbers of units by visit by 
  type of unit, e.g. advertised, similar, or acceptable unit  */


proc means noprint data=unit ;
  by control testerid ;
  var count inspect advunit inspadv advmeet advacc 
      similar inspsim accept inspacc ;
  output out=sumunit sum=number numinsp numadv advinsp advmtm 
    advaccm numsim siminsp numacc accinsp ;

/* create minority variables for all unit samples.  The first sample
  mnunit contains the means for neighborhood variables over the set
  of advertised or similar units.  The second sample contains 
  the counts of different types of units. The third sample contains
  information on follow-up contact.  */


data munits1 ;
   set mnunit ;
   mtestid=testerid ;

   maaskp=aaskp ;
   msaskp=saskp ;

       mamval=amval ; 
       mapci=apci ; 
       mapblk=apblk ; 
       maphsp=aphsp ;
       mapown=apown ; 
       mapov=apov ;

       msmval=smval ; 
       mspci=spci ; 
       mspblk=spblk ; 
       msphsp=sphsp ;
       mspown=spown ; 
       mspov=spov ;

   keep control mtestid mamval mapci mapblk maphsp mapown mapov maaskp 
             msmval mspci mspblk msphsp mspown mspov sdmval msaskp ;

proc sort data=munits1   ;
  by control mtestid ;


data munits2 ;
   set sumunit ;
   mtestid=testerid ;
   mnuminsp=numinsp ;
   mnumadv=numadv ;
   madvmtm=advmtm ;
   madvacc=advaccm ;
   madvinsp=advinsp ;
   mnumacc=numacc ;
   mnumsim=numsim ;
   msiminsp=siminsp ;
   keep control mtestid    mnuminsp    madvmtm
     madvacc     madvinsp    mnumacc    mnumadv 
     mnumsim    msiminsp    ;

proc sort data=munits2   ;
  by control mtestid ;

data munits3 ;
   set follow ;
   mtestid=testerid ;
   mfollow=follow ;
   keep control mtestid mfollow ;

proc sort data=munits3   ;
  by control mtestid ;

proc sort data=tests   ;
  by control mtestid ;

/* merge in unit level variables by minority testerid */


data tests ;
  merge tests (in=q1) munits1 (in=q2) munits2 (in=q3) munits3 (in=q4) ;
    by control mtestid ;
    if q1 ;

/* create majority variables for all unit samples.  The first sample
  mnunit contains the means for neighborhood variables over the set
  of advertised or similar units.  The second sample contains 
  the counts of different types of units. The third sample contains
  information on follow-up contact.  */


data wunits1 ;
   set mnunit ;
   wtestid=testerid ;

   waaskp=aaskp ;
   wsaskp=saskp ;


       wamval=amval ; 
       wapci=apci ; 
       wapblk=apblk ; 
       waphsp=aphsp ;
       wapown=apown ; 
       wapov=apov ;

       wsmval=smval ; 
       wspci=spci ; 
       wspblk=spblk ; 
       wsphsp=sphsp ;
       wspown=spown ; 
       wspov=spov ;


   keep control wtestid wamval wapci wapblk waphsp wapown wapov waaskp
              wsmval wspci wspblk wsphsp wspown wspov wsaskp ;

proc sort data=wunits1   ;
  by control wtestid ;

data wunits2 ;
   set sumunit ;
   wtestid=testerid ;
   wnuminsp=numinsp ;
   wnumadv=numadv ;
   wadvmtm=advmtm ;
   wadvacc=advaccm ;
   wadvinsp=advinsp ;
   wnumacc=numacc ;
   wnumsim=numsim ;
   wsiminsp=siminsp ;
   keep control wtestid    wnuminsp    wadvmtm  
     wadvacc    wadvinsp    wnumacc    wnumadv
     wnumsim    wsiminsp     ;

proc sort data=wunits2   ;
  by control wtestid ;

data wunits3 ;
   set follow ;
   wtestid=testerid ;
   wfollow=follow ;
   keep control wtestid wfollow ;

proc sort data=wunits3   ;
  by control wtestid ;

proc sort data=tests   ;
  by control wtestid ;

/* merge in unit level variables by majority testerid */

data tests ;
  merge tests (in=q1) wunits1 (in=q2) wunits2 (in=q3) wunits3 (in=q4) ;
    by control wtestid ;
  if q1 ;


/* merge in office information */ 

proc sort ; by control ;

data tests ;
  merge tests (in=q1) office ;
    by control ; if q1 ;

/* create treatment variables */


/* first, replace missing variables with zero for no treatment */ 


  if wnuminsp=. then wnuminsp=0 ;
  if wadvinsp=. then wadvinsp=0 ;
  if wsiminsp=. then wsiminsp=0 ;
  if wnumadv=. then wnumadv=0 ;
  if wadvmtm=. then wadvmtm=0 ;
  if wadvacc=. then wadvacc=0 ;
  if wnumsim=. then wnumsim=0 ;
  if wnumacc=. then wnumacc=0 ;
  if wfollow=. then wfollow=0 ;

  if mnuminsp=. then mnuminsp=0 ;
  if madvinsp=. then madvinsp=0 ;
  if msiminsp=. then msiminsp=0 ;
  if mnumadv=. then mnumadv=0 ;
  if madvmtm=. then madvmtm=0 ;
  if madvacc=. then madvacc=0 ;
  if mnumsim=. then mnumsim=0 ;
  if mnumacc=. then mnumacc=0 ;
  if mfollow=. then mfollow=0 ;

/* advertised unit available */

  if wavladv=1 or wavladv2=1 then wavailad=1 ;
    else if wavladv=2 or wavladv2=2 then wavailad=0 ;
    else if wadvmtm>0 then wavailad=1 ;
    else wavailad=0 ;

  if mavladv=1 or mavladv2=1 then mavailad=1 ;
    else if mavladv=2 or mavladv2=1 then mavailad=0 ;
    else if madvmtm>0 then mavailad=1 ;
    else mavailad=0 ;

/* similar unit available */

  if wsamebed=1 or wsamebe2=1 then wavailsm=1 ;
    else if wsamebed=2 or wsamebe2=2 then wavailsm=0 ;
    else if wnumsim>0 then wavailsm=1 ;
      else wavailsm=0 ;

  if msamebed=1 or msamebe2=1 then mavailsm=1 ;
    else if msamebed=2 or msamebe2=2 then mavailsm=0 ;
    else if mnumsim>0 then mavailsm=1 ;
      else mavailsm=0 ;

/*  Advertised unit inspected */

   if wadvinsp=0 then winspadv=0 ;
     else winspadv=1 ;
   if madvinsp=0 then minspadv=0 ;
     else minspadv=1 ;

/*  Similar unit inspected */

   if wsiminsp=0 then winspsim=0 ;
     else winspsim=1 ;

   if msiminsp=0 then minspsim=0 ;
     else minspsim=1 ;

/*  Number of units recommended */

   if wtotunit=-1 then wtotunit=. ;
   if wtotunit^=. then wrecom=wtotunit ;
     else wrecom=wadvmtm+wadvacc+wnumsim+wnumacc ;

   if mtotunit=-1 then mtotunit=. ;
   if mtotunit^=. then mrecom=mtotunit ;
     else mrecom=madvmtm+madvacc+mnumsim+mnumacc ;


  mrecomi=0 ;
  wrecomi=0 ;
  if mrecom>wrecom then mrecomi=1 ;
    else if mrecom<wrecom then wrecomi=1 ; 


/*  Number of units inspected */

  minspect=mnuminsp ;
  winspect=wnuminsp ;

  minspcti=0 ;
  winspcti=0 ;
  if minspect>winspect then minspcti=1 ;
    else if minspect<winspect then winspcti=1 ; 

/*  Agent asked about finances */

   if (wqincome=1 or wqincom2=1) and (wqasset=1 or wqasset2=1 or wqdownp=1 
        or wqdownp2=1) and 
      (wqdebts=1 or wqdebts2=1 or wqcredit=1 or wqcredi2=1) 
               then waskfin=1 ;
       else waskfin=0 ;

   if (mqincome=1 or mqincom2=1) and (mqasset=1 or mqasset2=1
        or mqdownp=1 or mqdownp2=1) and 
      (mqdebts=1 or mqdebts2=1 or mqcredit=1 or mqcredi2=1) 
               then maskfin=1 ;
       else maskfin=0 ;

/*  Agent qualified tester */

   if magqual=1 or magqual2=1 then mqual=1 ;
      else mqual=0 ;
   if wagqual=1 or wagqual2=1 then wqual=1 ;
      else wqual=0 ;

/*   asked about prequal */

   if waskbank=1 or waskban2=1 then waskpreq=1 ;
     else waskpreq=0 ;

   if maskbank=1 or maskban2=1 then maskpreq=1 ;
     else maskpreq=0 ;

/*  require prequal */

   if wtelbank=1 or wtelban2=1 then wreqpreq=1 ;
     else wreqpreq=0 ;

   if mtelbank=1 or mtelban2=1 then mreqpreq=1 ;
     else mreqpreq=0 ;

/*  offered financial assistence */

   if magfindf=1 or magfind2=1 then mfinhelp=1 ;
     else mfinhelp=0 ;

   if wagfindf=1 or wagfind2=1 then wfinhelp=1 ;
     else wfinhelp=0 ;

/*  provided names of lenders */

   if maglndr=1 or maglndr2=1 then mlenders=1 ;
     else mlenders=0 ;

   if waglndr=1 or waglndr2=1 then wlenders=1 ;
     else wlenders=0 ;

/*  discussed conventional financing */

   if mrfixed=1 or mrfixed2=1 or mradjst=1 or mradjst2=1
     then mconvfin=1 ; else mconvfin=0 ;

   if wrfixed=1 or wrfixed2=1 or wradjst=1 or wradjst2=1
     then wconvfin=1 ; else wconvfin=0 ;

/*  discussed FHA/VA financing  */

   if mrfhava=1 or mrfhava2=1 then mfhafin=1 ;
      else mfhafin=0 ;

   if wrfhava=1 or wrfhava2=1 then wfhafin=1 ;
      else wfhafin=0 ;

/*  Lender prequalified tester */

   if mprequal=1 or mprequa2=1 then mprequal=1 ;
     else mprequal=0 ;

   if wprequal=1 or wprequa2=1 then wprequal=1 ;
     else wprequal=0 ;

/*  Provided price range */

   if wsugpric=1 or wsugpri2=1 then wpricrng=1 ;
     else wpricrng=0 ;

   if msugpric=1 or msugpri2=1 then mpricrng=1 ;
     else mpricrng=0 ;

/*  Provide mortgage amount */

   if wsugmort=1 or wsugmor2=1 then wmortamt=1 ;
     else wmortamt=0 ;

   if msugmort=1 or msugmor2=1 then mmortamt=1 ;
     else mmortamt=0 ;

/*  Provided downpayment information */

   if wsugdown=1 or wsugdow2=1 then wdownpay=1 ;
     else wdownpay=0 ;

   if msugdown=1 or msugdow2=1 then mdownpay=1 ;
     else mdownpay=0 ;

/*  Tester asked to callback */

   if warngm2=1 then wcallbak=1 ;
       else wcallbak=0 ;

   if marngm2=1 then mcallbak=1 ;
       else mcallbak=0 ;

/*  No provision made for future contact */

   if warngm3=1 then wnofutcn=1 ;
       else wnofutcn=0 ;

   if marngm3=1 then mnofutcn=1 ;
       else mnofutcn=0 ;


/*  income variable */

if wincome=. or wincome=0 then wincome=mincome ;
if mincome=. or mincome=0 then mincome=wincome ;
if wincome=0 or mincome=0 then do ;
  wincome=. ; mincome=. ; end ;


if waskprc=. or waskprc=0 or maskprc=. or maskprc=0 then do ;
   waskprc=. ; maskprc=. ; end ;


/*  geography - Use location of white advertised unit unless missing.
  Progress first to minority advertised unit then to white similar
  unit ect.  Create a fill code variable to identify what information 
  was used to replace missing geographic information. */


if wamval=. and mamval=. and wsmval=. and msmval=. then do ;
   fillcode='XX' ;
   mval=mval00 ;
   pci=pci00 ;
   pblk=pctblk ;
   phsp=pcthisp ;
   pown=pctownoc ;
   pov=povrat90 ;
   end ;
else if wamval=. and mamval=. and wsmval=. then do ;
   fillcode='00' ;
   mval=msmval ;
   pci=mspci ;
   pblk=mspblk ;
   phsp=msphsp ;
   pown=mspown ;
   pov=mspov ;
   end ;
else if wamval=. and mamval=. then do ;
   fillcode='01' ;
   mval=wsmval ;
   pci=wspci ;
   pblk=wspblk ;
   phsp=wsphsp ;
   pown=wspown ;
   pov=wspov ;
   end ;
else if wamval=. then do ;
   fillcode='10' ;
   mval=mamval ;
   pci=mapci ;
   pblk=mapblk ;
   phsp=maphsp ;
   pown=mapown ;
   pov=mapov ;
   end ;
else if wamval^=. then do ;
   fillcode='11' ;
   mval=wamval ;
   pci=wapci ;
   pblk=wapblk ;
   phsp=waphsp ;
   pown=wapown ;
   pov=wapov ;
   end ;

  
/* Create racial composition variable based on ethnicity of the
  test */

if type='B' then prce=pblk ;
  else if type='H' then prce=phsp ;
  else prce=. ;


/* define common site labels */

  site=substr(control,1,2) ;
  type=substr(control,5,1) ;


  if site='AT' then do ;
    sitename='Atlanta' ;
    sitecode=520 ; 
    end ; 
  if site='AU' then do ;
    sitename='Austin' ;
    sitecode=640 ; 
    end ; 
  if site='PX' then do ;
    sitename='Phoenix' ;
    sitecode=6200 ; 
    end ; 
  if site='BR' then do ;
    sitename='Birmingham' ;
    sitecode=1000 ; 
    end ; 
  if site='CH' then do ;
    sitename='Chicago' ;
    sitecode=1600 ; 
    end ; 
  if site='DC' then do ;
    sitename='Washington, D.' ;
    sitecode=8840 ; 
    end ; 
  if site='DN' then do ;
    sitename='Denver' ;
    sitecode=2080 ; 
    end ; 
  if site='DS' then do ;
    sitename='Dayton' ;
    sitecode=2000 ; 
    end ; 
  if site='DT' then do ;
    sitename='Detroit' ;
    sitecode=2160 ; 
    end ; 
  if site='HO' then do ;
    sitename='Houston' ;
    sitecode=3360 ; 
    end ; 
  if site='LA' then do ;
    sitename='Los Angeles' ;
    sitecode=4480 ; 
    end ; 
  if site='MA' then do ;
    sitename='Macon' ;
    sitecode=4680 ; 
    end ; 
  if site='NY' then do ;
    sitename='New York' ;
    sitecode=5600 ; 
    end ; 
  if site='NO' then do ;
    sitename='New Orleans' ;
    sitecode=5560 ; 
    end ; 
  if site='OR' then do ;
    sitename='Orlando' ;
    sitecode=5960 ; 
    end ; 
  if site='PH' then do ;
    sitename='Philadelphia' ;
    sitecode=6160 ; 
    end ; 
  if site='PT' then do ;
    sitename='Pittsburgh' ;
    sitecode=6280 ; 
    end ; 
  if site='PU' then do ;
    sitename='Pueblo' ;
    sitecode=6560 ; 
    end ; 
  if site='SA' then do ;
    sitename='San Antonio' ;
    sitecode=7240 ; 
    end ; 
  if site='SD' then do ;
    sitename='San Diego' ;
    sitecode=7320 ; 
    end ; 
  if site='TC' then do ;
    sitename='Tuscon' ;
    sitecode=8520 ; 
    end ; 


  year='2000' ;
  count=1 ;


keep sitename sitecode year type site count control mtestid wtestid
  wavailad mavailad wavailsm mavailsm winspadv minspadv 
  winspsim minspsim winspect minspect wrecom mrecom 
  winspcti minspcti wrecomi mrecomi waaskp maaskp wsaskp msaskp
  wcallbak mcallbak wnofutcn mnofutcn wfollow mfollow wqual mqual
  waskfin maskfin waskpreq maskpreq wreqpreq mreqpreq
  wfinhelp mfinhelp wlenders mlenders wconvfin mconvfin
  wfhafin mfhafin wprequal mprequal wpricrng mpricrng
  wmortamt mmortamt wdownpay mdownpay mincom2 wincom2
  sameagnt wcuremp mcuremp wemplngt memplngt 
  wstudnt mstudnt whighedu mhighedu wpegai wpegai
  whhegai mhhegai wcurtenr mcurtenr wmortfin mmortfin
  wexpernc mexpernc wtimecur mtimecur 
  whhrel1 whhrel2 whhrel3 whhrel4 whhrel5
  mhhrel1 mhhrel2 mhhrel3 mhhrel4 mhhrel5
  wmarried mmarried wchild mchild wpricell mpricell
  wpricehl mpricehl wlength mlength wvdate_m wvdate_d
  wvdate_y mvdate_m mvdate_d mvdate_y wincome mincome
  mval pci pblk phsp pown pov order prce fillcode 
  mtotasst mcrdpay mcrdbal mbedmin mbedreq msex
  mage mtsex 
  wtotasst wcrdpay wcrdbal wbedmin wbedreq wsex
  wage wtsex ;


proc freq ;
  tables   fillcode sameagnt order
           wavailad*mavailad 
           wavailsm*mavailsm 
           winspadv*minspadv 
           winspsim*minspsim 
           wrecomi*mrecomi 
           winspcti*minspcti 
           wcallbak*mcallbak 
           wnofutcn*mnofutcn 
           wfollow*mfollow 
           wqual*mqual
  waskfin*maskfin waskpreq*maskpreq wreqpreq*mreqpreq
  wfinhelp*mfinhelp wlenders*mlenders wconvfin*mconvfin
  wfhafin*mfhafin wprequal*mprequal wpricrng*mpricrng
  wmortamt*mmortamt wdownpay*mdownpay ;


proc means ;
   var wrecom mrecom winspect minspect waaskp maaskp wsaskp msaskp
       wincome mincome mval pci pblk phsp pown pov whighedu mhighedu  ;



data hds2000.fnslsmrg ;
  set tests ; 
run;












